package common

import (
	"bytes"
	"encoding/csv"
	"encoding/json"
	"net/http"
	"time"
)

func HTTPGet(url string, timeout time.Duration) (*bytes.Buffer, error) {
	buf := new(bytes.Buffer)
	client := &http.Client{
		Timeout: timeout,
	}
	resp, err := client.Get(url)
	if err != nil {
		return buf, err
	}

	defer resp.Body.Close()

	if _, err := buf.ReadFrom(resp.Body); err != nil {
		return nil, err
	}

	return buf, nil
}

func HTTPGetJson(url string, into interface{}, timeout time.Duration) error {
	body, err := HTTPGet(url, timeout)
	if err != nil {
		return err
	}
	return json.NewDecoder(body).Decode(into)
}

func HTTPGetCsv(url string, sep rune, timeout time.Duration) ([][]string, error) {
	body, err := HTTPGet(url, timeout)
	if err != nil {
		return nil, err
	}
	r := csv.NewReader(body)
	r.Comma = sep
	return r.ReadAll()
}
